about summary refs log tree commit diff
path: root/Src/Modules/example.c
diff options
context:
space:
mode:
authorTanaka Akira <akr@users.sourceforge.net>1999-12-15 21:29:55 +0000
committerTanaka Akira <akr@users.sourceforge.net>1999-12-15 21:29:55 +0000
commit03e230cc54103d18e9c8a18208c7d27805400a71 (patch)
treeefb79fe4d798134599ec6c90cd9912e59ccca69d /Src/Modules/example.c
parentb9c19b15a6f01279ddcf32ca6fa51894a64a6c16 (diff)
downloadzsh-03e230cc54103d18e9c8a18208c7d27805400a71.tar.gz
zsh-03e230cc54103d18e9c8a18208c7d27805400a71.tar.xz
zsh-03e230cc54103d18e9c8a18208c7d27805400a71.zip
manual:9047
Diffstat (limited to 'Src/Modules/example.c')
-rw-r--r--Src/Modules/example.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/Src/Modules/example.c b/Src/Modules/example.c
index bf4ad60fb..43199e350 100644
--- a/Src/Modules/example.c
+++ b/Src/Modules/example.c
@@ -159,7 +159,7 @@ ex_wrapper(List list, FuncWrap w, char *name)
 }
 
 /*
  * boot_ is executed when the module is loaded.
  */
 
 static struct builtin bintab[] = {
@@ -188,7 +188,7 @@ static struct funcwrap wrapper[] = {
 
 /**/
 int
-setup_(Module m)
+setup_example(Module m)
 {
     printf("The example module has now been set up.\n");
     fflush(stdout);
@@ -197,7 +197,7 @@ setup_(Module m)
 
 /**/
 int
-boot_(Module m)
+boot_example(Module m)
 {
     intparam = 42;
     strparam = ztrdup("example");
@@ -214,7 +214,7 @@ boot_(Module m)
 
 /**/
 int
-cleanup_(Module m)
+cleanup_example(Module m)
 {
     deletebuiltins(m->nam, bintab, sizeof(bintab)/sizeof(*bintab));
     deleteconddefs(m->nam, cotab, sizeof(cotab)/sizeof(*cotab));
@@ -226,7 +226,7 @@ cleanup_(Module m)
 
 /**/
 int
-finish_(Module m)
+finish_example(Module m)
 {
     printf("Thank you for using the example module.  Have a nice day.\n");
     fflush(stdout);
@@ -159,7 +159,7 @@ ex_wrapper(List list, FuncWrap w, char *name)
 
 /*
- * boot_ is executed when the module is loaded.
+ * boot_example is executed when the module is loaded.
  */
 